MbxSecureFile class

Constructors

MbxSecureFile()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

readEncryptedData(String passphrase) Future<String?>
Read and decrypt content
saveEncryptedData(String content, String passphrase) Future<void>
Save encrypted content to file